@@ -9,6 +9,8 @@
 
 #include "common.h"
 
+class SearchDialog;
+
 namespace Ui {
     class TravelSearchWindow;
 }
@@ -47,7 +49,13 @@ public:
     TravelSearchWindow(QWidget *parent = 0);
     ~TravelSearchWindow();
 
+    enum FavoriteSelectMode {FavoriteTo, FavoriteFrom};
+
+    int favoriteSelectMode;
+
     void setPlace(Place place, bool isFrom);
+    void setPlaceFrom(Place place);
+    void setPlaceTo(Place place);
 
 protected:
     void changeEvent(QEvent *e);
@@ -58,17 +66,28 @@ private:
     Place placeTo;
     bool portraitMode;
     QNetworkAccessManager *manager;
-    Place searchPlace();
+    Place searchPlace(SearchDialog *search);
     QMaemo5DatePickSelector *datePicker;
     QMaemo5TimePickSelector *timePicker;
+    SearchDialog *searchFromDialog;
+    SearchDialog *searchToDialog;
+    void showFavoriteMessage(Place place, int mode);
+    QMaemo5ValueButton *dateButton;
+    QMaemo5ValueButton *timeButton;
 
 private slots:
+    void on_btnNow_clicked();
+    void on_btnToFavorite_clicked();
+    void on_btnFromFavorite_clicked();
+    void on_actionSwitch_direction_triggered();
+    void on_actionAddFavorite_triggered();
     void on_tblResults_clicked(QModelIndex index);
     void on_pushButton_clicked();
     void on_btnPlaceTo_clicked();
     void on_btnPlaceFrom_clicked();
     void orientationChanged();
     void replyFinished(QNetworkReply *reply);
+    void favoritePlaceSelected(Place place);
 };
 
 #endif // ROUTESEARCHWINDOW_H
